# Files
from . import file
from . import string
from . import json
from . import formadator
from . import time
from . import array
from . import attribute
from . import logger
from . import http
from . import database
from . import dicts
from . import token
from . import output
from . import system
from . import shredder
from . import url

# Folders
# from . import lookup

def files():
    print(16)