file_extensions={
"None":"text",
"ogm":"video",
"doc":"text",
"class":"code",
"js":"code",
"swift":"code",
"cc":"code",
"tga":"image",
"ape":"audio",
"woff2":"font",
"cab":"archiv",
"whl":"archiv",
"mpe":"video",
"rmvb":"video",
"srt":"video",
"pdf":"text",
"xz":"archiv",
"exe":"exec",
"m4a":"audio",
"crx":"exec",
"vob":"video",
"tif":"image",
"gz":"archiv",
"roq":"video",
"m4v":"video",
"gif":"image",
"rb":"code",
"3g2":"video",
"m4":"code",
"ar":"archiv",
"vb":"code",
"sid":"audio",
"ai":"image",
"wma":"audio",
"pea":"archiv",
"bmp":"image",
"py":"code",
"mp4":"video",
"m4p":"video",
"ods":"sheet",
"jpeg":"image",
"command":"exec",
"azw4":"book",
"otf":"font",
"ebook":"text",
"rtf":"text",
"ttf":"font",
"mobi":"book",
"ra":"audio",
"flv":"video",
"ogv":"video",
"mpg":"video",
"xls":"sheet",
"jpg":"image",
"mkv":"video",
"nsv":"video",
"mp3":"audio",
"kmz":"image",
"java":"code",
"lua":"code",
"m2v":"video",
"deb":"archiv",
"rst":"text",
"csv":"sheet",
"pls":"audio",
"pak":"archiv",
"egg":"archiv",
"tlz":"archiv",
"c":"code",
"cbz":"book",
"xcodeproj":"code",
"iso":"archiv",
"xm":"audio",
"azw":"book",
"webm":"video",
"3ds":"image",
"azw6":"book",
"azw3":"book",
"php":"code",
"kml":"image",
"woff":"font",
"log":"text",
"zipx":"archiv",
"3gp":"video",
"po":"code",
"mpa":"audio",
"mng":"video",
"wps":"text",
"wpd":"text",
"a":"archiv",
"s7z":"archiv",
"ics":"sheet",
"tex":"text",
"go":"code",
"ps":"image",
"org":"text",
"sh":"exec",
"msg":"text",
"xml":"code",
"cpio":"archiv",
"epub":"book",
"docx":"text",
"lha":"archiv",
"flac":"audio",
"odp":"slide",
"wmv":"video",
"vcxproj":"code",
"mar":"archiv",
"eot":"font",
"less":"web",
"asf":"video",
"apk":"archiv",
"css":"web",
"mp2":"video",
"odt":"text",
"patch":"code",
"wav":"audio",
"msi":"exec",
"rs":"code",
"gsm":"audio",
"ogg":"video",
"cbr":"book",
"azw1":"book",
"m":"code",
"dds":"image",
"h":"code",
"dmg":"archiv",
"mid":"audio",
"psd":"image",
"dwg":"image",
"aac":"audio",
"s3m":"audio",
"cs":"code",
"cpp":"code",
"au":"audio",
"aiff":"audio",
"diff":"code",
"avi":"video",
"bat":"exec",
"jsp":"code",
"htm":"code",
"html":"code",
"pages":"text",
"bin":"exec",
"txt":"text",
"rpm":"archiv",
"m3u":"audio",
"max":"image",
"vcf":"sheet",
"svg":"image",
"ppt":"slide",
"clj":"code",
"png":"image",
"svi":"video",
"tiff":"image",
"tgz":"archiv",
"mxf":"video",
"7z":"archiv",
"drc":"video",
"yuv":"video",
"mov":"video",
"tbz2":"archiv",
"bz2":"archiv",
"gpx":"image",
"shar":"archiv",
"xcf":"image",
"dxf":"image",
"jar":"archiv",
"qt":"video",
"tar":"archiv",
"xpi":"archiv",
"zip":"archiv",
"thm":"image",
"cxx":"code",
"3dm":"image",
"rar":"archiv",
"md":"text",
"scss":"web",
"mpv":"video",
"webp":"image",
"war":"archiv",
"pl":"code",
"xlsx":"sheet",
"mpeg":"video",
"aaf":"video",
"avchd":"video",
"mod":"audio",
"rm":"video",
"it":"audio",
"wasm":"web",
"el":"code",
"eps":"image",
"OTHER":"OTHER"
}


video_extensions={
"ogm":"video",
"mpe":"video",
"rmvb":"video",
"srt":"video",
"vob":"video",
"roq":"video",
"m4v":"video",
"3g2":"video",
"mp4":"video",
"m4p":"video",
"flv":"video",
"ogv":"video",
"mpg":"video",
"mkv":"video",
"nsv":"video",
"m2v":"video",
"webm":"video",
"3gp":"video",
"mng":"video",
"wmv":"video",
"asf":"video",
"mp2":"video",
"ogg":"video",
"avi":"video",
"svi":"video",
"mxf":"video",
"drc":"video",
"yuv":"video",
"mov":"video",
"qt":"video",
"mpv":"video",
"mpeg":"video",
"aaf":"video",
"avchd":"video",
"rm":"video"
}



audio_extensions={
"ape":"audio",
"m4a":"audio",
"sid":"audio",
"wma":"audio",
"ra":"audio",
"mp3":"audio",
"pls":"audio",
"xm":"audio",
"mpa":"audio",
"flac":"audio",
"wav":"audio",
"gsm":"audio",
"mid":"audio",
"aac":"audio",
"s3m":"audio",
"au":"audio",
"aiff":"audio",
"m3u":"audio",
"mod":"audio",
"it":"audio"
}


image_extensions={
"tga":"image",
"tif":"image",
"gif":"image",
"ai":"image",
"bmp":"image",
"jpeg":"image",
"jpg":"image",
"kmz":"image",
"3ds":"image",
"kml":"image",
"ps":"image",
"dds":"image",
"psd":"image",
"dwg":"image",
"max":"image",
"svg":"image",
"png":"image",
"tiff":"image",
"gpx":"image",
"xcf":"image",
"dxf":"image",
"thm":"image",
"3dm":"image",
"webp":"image",
"eps":"image"    
}
