from setuptools import setup

setup(name='utilum',
      version='0.1.2',
      description='Basic Utilities Package',
      packages = ['utilum', 'utilum/lookup'],
      install_requires = [],
      zip_safe = False,
      )